@@ -2,7 +2,7 @@ use crate::config::ParsingMode;
 use crate::error::{Id3v2Error, Id3v2ErrorKind, Result};
 use crate::id3::v2::{FrameFlags, FrameHeader, FrameId};
 use crate::macros::parse_mode_choice;
-use crate::util::text::{decode_text, encode_text, TextDecodeOptions, TextEncoding};
+use crate::util::text::{TextDecodeOptions, TextEncoding, decode_text, encode_text};
 
 use std::borrow::Cow;
 use std::hash::{Hash, Hasher};
@@ -134,17 +134,21 @@ mod tests {
 
 		let bytes = ufid_no_owner.as_bytes();
 
-		assert!(UniqueFileIdentifierFrame::parse(
-			&mut &bytes[..],
-			FrameFlags::default(),
-			ParsingMode::Strict
-		)
-		.is_err());
-		assert!(UniqueFileIdentifierFrame::parse(
-			&mut &bytes[..],
-			FrameFlags::default(),
-			ParsingMode::BestAttempt
-		)
-		.is_ok());
+		assert!(
+			UniqueFileIdentifierFrame::parse(
+				&mut &bytes[..],
+				FrameFlags::default(),
+				ParsingMode::Strict
+			)
+			.is_err()
+		);
+		assert!(
+			UniqueFileIdentifierFrame::parse(
+				&mut &bytes[..],
+				FrameFlags::default(),
+				ParsingMode::BestAttempt
+			)
+			.is_ok()
+		);
 	}
 }
