@@ -1,9 +1,9 @@
 #[cfg(test)]
 mod tests;
 
-use super::frame::{Frame, EMPTY_CONTENT_DESCRIPTOR};
+use super::frame::{EMPTY_CONTENT_DESCRIPTOR, Frame};
 use super::header::{Id3v2TagFlags, Id3v2Version};
-use crate::config::{global_options, WriteOptions};
+use crate::config::{WriteOptions, global_options};
 use crate::error::{LoftyError, Result};
 use crate::id3::v1::GENRES;
 use crate::id3::v2::frame::{FrameRef, MUSICBRAINZ_UFID_OWNER};
@@ -13,7 +13,7 @@ use crate::id3::v2::items::{
 };
 use crate::id3::v2::util::mappings::TIPL_MAPPINGS;
 use crate::id3::v2::util::pairs::{
-	format_number_pair, set_number, NUMBER_PAIR_KEYS, NUMBER_PAIR_SEPARATOR,
+	NUMBER_PAIR_KEYS, NUMBER_PAIR_SEPARATOR, format_number_pair, set_number,
 };
 use crate::id3::v2::{BinaryFrame, FrameHeader, FrameId, KeyValueFrame, TimestampFrame};
 use crate::mp4::AdvisoryRating;
@@ -23,7 +23,7 @@ use crate::tag::items::{Lang, Timestamp, UNKNOWN_LANGUAGE};
 use crate::tag::{Accessor, ItemKey, ItemValue, MergeTag, SplitTag, Tag, TagExt, TagItem, TagType};
 use crate::util::flag_item;
 use crate::util::io::{FileLike, Length, Truncate};
-use crate::util::text::{decode_text, TextDecodeOptions, TextEncoding};
+use crate::util::text::{TextDecodeOptions, TextEncoding, decode_text};
 
 use std::borrow::Cow;
 use std::io::{Cursor, Write};
@@ -251,7 +251,10 @@ impl Id3v2Tag {
 	/// assert_eq!(titles.next(), Some("Foo"));
 	/// assert_eq!(titles.next(), Some("Bar"));
 	/// ```
-	pub fn get_texts(&self, id: &FrameId<'_>) -> Option<impl Iterator<Item = &str>> {
+	pub fn get_texts<'a>(
+		&'a self,
+		id: &FrameId<'_>,
+	) -> Option<impl Iterator<Item = &'a str> + use<'a>> {
 		if let Some(Frame::Text(TextInformationFrame { value, .. })) = self.get(id) {
 			return Some(value.split(V4_MULTI_VALUE_SEPARATOR));
 		}
@@ -392,9 +395,9 @@ impl Id3v2Tag {
 	/// # Examples
 	///
 	/// ```rust
+	/// use lofty::TextEncoding;
 	/// use lofty::id3::v2::{Frame, FrameFlags, FrameId, Id3v2Tag, TextInformationFrame};
 	/// use lofty::tag::TagExt;
-	/// use lofty::TextEncoding;
 	/// use std::borrow::Cow;
 	///
 	/// const MOOD_FRAME_ID: FrameId<'static> = FrameId::Valid(Cow::Borrowed("TMOO"));
@@ -425,7 +428,10 @@ impl Id3v2Tag {
 	/// assert!(tag.is_empty());
 	/// # Ok(()) }
 	/// ```
-	pub fn remove(&mut self, id: &FrameId<'_>) -> impl Iterator<Item = Frame<'static>> + '_ {
+	pub fn remove<'a>(
+		&'a mut self,
+		id: &FrameId<'_>,
+	) -> impl Iterator<Item = Frame<'static>> + use<'a> {
 		// TODO: drain_filter
 		let mut split_idx = 0_usize;
 
@@ -515,7 +521,7 @@ impl Id3v2Tag {
 	}
 
 	fn split_num_pair(&self, id: &FrameId<'_>) -> (Option<u32>, Option<u32>) {
-		if let Some(Frame::Text(TextInformationFrame { ref value, .. })) = self.get(id) {
+		if let Some(Frame::Text(TextInformationFrame { value, .. })) = self.get(id) {
 			let mut split = value
 				.split(&[V4_MULTI_VALUE_SEPARATOR, NUMBER_PAIR_SEPARATOR][..])
 				.flat_map(str::parse::<u32>);
@@ -538,7 +544,7 @@ impl Id3v2Tag {
 					}
 				}
 			},
-		};
+		}
 	}
 
 	/// Returns all genres contained in a `TCON` frame.
@@ -546,7 +552,7 @@ impl Id3v2Tag {
 	/// This will translate any numeric genre IDs to their textual equivalent.
 	/// ID3v2.4-style multi-value fields will be split as normal.
 	pub fn genres(&self) -> Option<impl Iterator<Item = &str>> {
-		if let Some(Frame::Text(TextInformationFrame { ref value, .. })) = self.get(&GENRE_ID) {
+		if let Some(Frame::Text(TextInformationFrame { value, .. })) = self.get(&GENRE_ID) {
 			return Some(GenresIter::new(value, false));
 		}
 
@@ -800,7 +806,7 @@ impl Accessor for Id3v2Tag {
 
 		if genres.peek().is_none() {
 			return Some(Cow::Borrowed(first));
-		};
+		}
 
 		let mut joined = String::from(first);
 		for genre in genres {
@@ -1091,7 +1097,7 @@ fn handle_tag_split(tag: &mut Tag, frame: &mut Frame<'_>) -> bool {
 		//       Maybe ItemKey could use a "TXXX:" prefix eventually, so we would store
 		//       "TXXX:MusicBrainz Album Id" instead of "MusicBrainz Album Id".
 		// Store TXXX/WXXX frames by their descriptions, rather than their IDs
-		Frame::UserText(ExtendedTextFrame {
+		&mut Frame::UserText(ExtendedTextFrame {
 			ref description,
 			ref content,
 			..
@@ -1106,7 +1112,7 @@ fn handle_tag_split(tag: &mut Tag, frame: &mut Frame<'_>) -> bool {
 
 			return FRAME_CONSUMED;
 		},
-		Frame::UserUrl(ExtendedUrlFrame {
+		&mut Frame::UserUrl(ExtendedUrlFrame {
 			ref description,
 			ref content,
 			..
@@ -1122,7 +1128,7 @@ fn handle_tag_split(tag: &mut Tag, frame: &mut Frame<'_>) -> bool {
 			return FRAME_CONSUMED;
 		},
 
-		Frame::UniqueFileIdentifier(UniqueFileIdentifierFrame {
+		&mut Frame::UniqueFileIdentifier(UniqueFileIdentifierFrame {
 			ref owner,
 			ref identifier,
 			..
@@ -1179,7 +1185,7 @@ fn handle_tag_split(tag: &mut Tag, frame: &mut Frame<'_>) -> bool {
 		},
 
 		Frame::Picture(AttachedPictureFrame {
-			ref mut picture, ..
+			picture, ..
 		}) => {
 			tag.push_picture(std::mem::replace(picture, TOMBSTONE_PICTURE));
 			return FRAME_CONSUMED;
@@ -1216,7 +1222,7 @@ fn handle_tag_split(tag: &mut Tag, frame: &mut Frame<'_>) -> bool {
 		},
 		Frame::Url(UrlLinkFrame {
 			header: FrameHeader {id, .. },
-			ref mut content, ..
+			content, ..
 		}) => {
 			let item_key = ItemKey::from_key(TagType::Id3v2, id.as_str());
 			tag.items.push(TagItem::new(
@@ -1299,10 +1305,10 @@ impl MergeTag for SplitTagRemainder {
 			content: String,
 		}
 
-		fn join_language_items(
-			tag: &mut Tag,
+		fn join_language_items<'a>(
+			tag: &'a mut Tag,
 			key: &ItemKey,
-		) -> Option<impl Iterator<Item = JoinedLanguageItem>> {
+		) -> Option<impl Iterator<Item = JoinedLanguageItem> + use<'a>> {
 			let mut items = tag.take(key).collect::<Vec<_>>();
 			if items.is_empty() {
 				return None;
@@ -1489,7 +1495,7 @@ impl MergeTag for SplitTagRemainder {
 			let existing_tipl = merged.take_first(&FrameId::Valid(Cow::Borrowed("TIPL")));
 			if let Some(mut tipl_frame) = existing_tipl {
 				if let Frame::KeyValue(KeyValueFrame {
-					key_value_pairs: ref mut existing,
+					key_value_pairs: existing,
 					..
 				}) = &mut tipl_frame
 				{
