@@ -5,11 +5,11 @@ use super::Id3v2TagFlags;
 use crate::config::WriteOptions;
 use crate::error::{LoftyError, Result};
 use crate::file::FileType;
+use crate::id3::v2::Id3v2Tag;
 use crate::id3::v2::frame::FrameRef;
 use crate::id3::v2::tag::Id3v2TagRef;
 use crate::id3::v2::util::synchsafe::SynchsafeInteger;
-use crate::id3::v2::Id3v2Tag;
-use crate::id3::{find_id3v2, FindId3v2Config};
+use crate::id3::{FindId3v2Config, find_id3v2};
 use crate::macros::{err, try_vec};
 use crate::probe::Probe;
 use crate::util::io::{FileLike, Length, Truncate};
@@ -296,7 +296,7 @@ mod tests {
 	use crate::id3::v2::{Id3v2Tag, Id3v2TagFlags};
 	use crate::prelude::*;
 
-	#[test]
+	#[test_log::test]
 	fn id3v2_write_crc32() {
 		let mut tag = Id3v2Tag::default();
 		tag.set_artist(String::from("Foo artist"));
