@@ -1,6 +1,6 @@
+use super::AiffFile;
 use super::properties::AiffProperties;
 use super::tag::{AiffTextChunks, Comment};
-use super::AiffFile;
 use crate::config::ParseOptions;
 use crate::error::Result;
 use crate::id3::v2::tag::Id3v2Tag;
@@ -67,7 +67,7 @@ where
 
 	let mut chunks = Chunks::<BigEndian>::new(file_len);
 
-	while chunks.next(data).is_ok() {
+	while let Ok(true) = chunks.next(data) {
 		match &chunks.fourcc {
 			b"ID3 " | b"id3 " if parse_options.read_tags => {
 				let tag = chunks.id3_chunk(data, parse_options)?;
@@ -163,7 +163,7 @@ where
 		}
 	} else {
 		properties = AiffProperties::default();
-	};
+	}
 
 	Ok(AiffFile {
 		properties,
