@@ -1,7 +1,7 @@
 use crate::error::Result;
 use crate::macros::err;
-use crate::mp4::ilst::data_type::DataType;
 use crate::mp4::AtomIdent;
+use crate::mp4::ilst::data_type::DataType;
 use crate::picture::Picture;
 
 use std::fmt::{Debug, Formatter};
@@ -161,7 +161,7 @@ impl<'a> Atom<'a> {
 	/// );
 	/// assert_eq!(atom.into_data().count(), 1);
 	/// ```
-	pub fn into_data(self) -> impl Iterator<Item = AtomData> {
+	pub fn into_data(self) -> impl Iterator<Item = AtomData> + use<> {
 		self.data.into_iter()
 	}
 
