@@ -7,13 +7,13 @@ mod r#ref;
 pub(crate) mod write;
 
 use super::AtomIdent;
-use crate::config::{global_options, WriteOptions};
+use crate::config::{WriteOptions, global_options};
 use crate::error::LoftyError;
 use crate::mp4::ilst::atom::AtomDataStorage;
 use crate::picture::{Picture, PictureType, TOMBSTONE_PICTURE};
 use crate::tag::companion_tag::CompanionTag;
 use crate::tag::{
-	try_parse_year, Accessor, ItemKey, ItemValue, MergeTag, SplitTag, Tag, TagExt, TagItem, TagType,
+	Accessor, ItemKey, ItemValue, MergeTag, SplitTag, Tag, TagExt, TagItem, TagType, try_parse_year,
 };
 use crate::util::flag_item;
 use crate::util::io::{FileLike, Length, Truncate};
@@ -251,7 +251,10 @@ impl Ilst {
 	/// let title = ilst.get(&TITLE_IDENTIFIER);
 	/// assert!(title.is_none());
 	/// ```
-	pub fn remove(&mut self, ident: &AtomIdent<'_>) -> impl Iterator<Item = Atom<'static>> + '_ {
+	pub fn remove<'a>(
+		&'a mut self,
+		ident: &AtomIdent<'_>,
+	) -> impl Iterator<Item = Atom<'static>> + use<'a> {
 		// TODO: drain_filter
 		let mut split_idx = 0_usize;
 
@@ -456,7 +459,7 @@ impl Ilst {
 					return Some(u16::from_be_bytes([
 						data[expected_size - 2],
 						data[expected_size - 1],
-					]))
+					]));
 				},
 				_ => {},
 			}
@@ -685,7 +688,7 @@ impl SplitTag for Ilst {
 					code: DataType::Reserved,
 					data,
 				} if Vec::len(data) >= 6 => {
-					if let AtomIdent::Fourcc(ref fourcc) = ident {
+					if let &mut AtomIdent::Fourcc(ref fourcc) = ident {
 						match fourcc {
 							b"trkn" => {
 								let current = u16::from_be_bytes([data[2], data[3]]);
@@ -880,8 +883,8 @@ impl From<Tag> for Ilst {
 #[cfg(test)]
 mod tests {
 	use crate::config::{ParseOptions, ParsingMode, WriteOptions};
-	use crate::mp4::ilst::atom::AtomDataStorage;
 	use crate::mp4::ilst::TITLE;
+	use crate::mp4::ilst::atom::AtomDataStorage;
 	use crate::mp4::read::AtomReader;
 	use crate::mp4::{AdvisoryRating, Atom, AtomData, AtomIdent, DataType, Ilst, Mp4File};
 	use crate::picture::{MimeType, Picture, PictureType};
@@ -1133,11 +1136,13 @@ mod tests {
 		const PADDING_SIZE: usize = 990;
 
 		let file_bytes = read_path("tests/files/assets/ilst_trailing_padding.m4a");
-		assert!(Mp4File::read_from(
-			&mut Cursor::new(&file_bytes),
-			ParseOptions::new().read_properties(false)
-		)
-		.is_ok());
+		assert!(
+			Mp4File::read_from(
+				&mut Cursor::new(&file_bytes),
+				ParseOptions::new().read_properties(false)
+			)
+			.is_ok()
+		);
 
 		let mut ilst;
 		let old_free_size;
