@@ -4,11 +4,11 @@ use crate::config::{ParseOptions, WriteOptions};
 use crate::error::{FileEncodingError, LoftyError, Result};
 use crate::file::FileType;
 use crate::macros::{decode_err, err, try_vec};
-use crate::mp4::atom_info::{AtomIdent, AtomInfo, ATOM_HEADER_LEN, FOURCC_LEN};
-use crate::mp4::ilst::r#ref::AtomRef;
-use crate::mp4::read::{atom_tree, find_child_atom, meta_is_full, verify_mp4, AtomReader};
-use crate::mp4::write::{AtomWriter, AtomWriterCompanion, ContextualAtom};
 use crate::mp4::AtomData;
+use crate::mp4::atom_info::{ATOM_HEADER_LEN, AtomIdent, AtomInfo, FOURCC_LEN};
+use crate::mp4::ilst::r#ref::AtomRef;
+use crate::mp4::read::{AtomReader, atom_tree, find_child_atom, meta_is_full, verify_mp4};
+use crate::mp4::write::{AtomWriter, AtomWriterCompanion, ContextualAtom};
 use crate::picture::{MimeType, Picture};
 use crate::util::alloc::VecFallibleCapacity;
 use crate::util::io::{FileLike, Length, Truncate};
@@ -678,12 +678,12 @@ where
 		match value {
 			AtomData::UTF8(text) => write_data(DataType::Utf8, text.as_bytes(), writer)?,
 			AtomData::UTF16(text) => write_data(DataType::Utf16, text.as_bytes(), writer)?,
-			AtomData::Picture(ref pic) => write_picture(pic, writer)?,
+			AtomData::Picture(pic) => write_picture(pic, writer)?,
 			AtomData::SignedInteger(int) => write_signed_int(*int, writer)?,
 			AtomData::UnsignedInteger(uint) => write_unsigned_int(*uint, writer)?,
 			AtomData::Bool(b) => write_bool(*b, writer)?,
-			AtomData::Unknown { code, ref data } => write_data(*code, data, writer)?,
-		};
+			AtomData::Unknown { code, data } => write_data(*code, data, writer)?,
+		}
 	}
 
 	Ok(())
