@@ -1,9 +1,9 @@
 pub(super) mod properties;
 
 use super::tag::VorbisComments;
+use crate::config::ParseOptions;
 use crate::error::Result;
 use crate::ogg::constants::SPEEXHEADER;
-use crate::probe::ParseOptions;
 use properties::SpeexProperties;
 
 use std::io::{Read, Seek};
@@ -28,8 +28,7 @@ impl SpeexFile {
 	where
 		R: Read + Seek,
 	{
-		let file_information =
-			super::read::read_from(reader, SPEEXHEADER, &[], 2, parse_options.parsing_mode)?;
+		let file_information = super::read::read_from(reader, SPEEXHEADER, &[], 2, parse_options)?;
 
 		Ok(Self {
 			properties: if parse_options.read_properties {
@@ -37,8 +36,8 @@ impl SpeexFile {
 			} else {
 				SpeexProperties::default()
 			},
-			// Safe to unwrap, a metadata packet is mandatory in Speex
-			vorbis_comments_tag: file_information.0.unwrap(),
+			// A metadata packet is mandatory in Speex
+			vorbis_comments_tag: file_information.0.unwrap_or_default(),
 		})
 	}
 }
