@@ -100,6 +100,26 @@ impl MimeType {
 			MimeType::Unknown(unknown) => unknown,
 		}
 	}
+
+	/// Returns the extension for the `MimeType` if it is known
+	///
+	/// # Examples
+	///
+	/// ```rust
+	/// use lofty::picture::MimeType;
+	///
+	/// assert_eq!(MimeType::Jpeg.ext(), Some("jpg"));
+	/// ```
+	pub fn ext(&self) -> Option<&str> {
+		match self {
+			MimeType::Jpeg => Some("jpg"),
+			MimeType::Png => Some("png"),
+			MimeType::Tiff => Some("tif"),
+			MimeType::Bmp => Some("bmp"),
+			MimeType::Gif => Some("gif"),
+			MimeType::Unknown(_) => None,
+		}
+	}
 }
 
 impl Display for MimeType {
@@ -469,7 +489,7 @@ impl Picture {
 	///
 	/// * This is for reading picture data only, from a [`File`](std::fs::File) for example.
 	/// * `pic_type` will always be [`PictureType::Other`], be sure to change it accordingly if
-	///    writing.
+	///   writing.
 	///
 	/// # Errors
 	///
