@@ -187,7 +187,7 @@ where
 			}
 
 			total_samples = block_header.total_samples;
-			properties.bit_depth = ((((flags & BYTES_PER_SAMPLE_MASK) + 1) * 8) - ((flags & BIT_DEPTH_SHIFT_MASK) >> BIT_DEPTH_SHL)) as u8;
+			properties.bit_depth = (((flags & BYTES_PER_SAMPLE_MASK) + 1) * 8).saturating_sub((flags & BIT_DEPTH_SHIFT_MASK) >> BIT_DEPTH_SHL) as u8;
 
 			properties.version = block_header.version;
 			properties.lossless = flags & FLAG_HYBRID_COMPRESSION == 0;
@@ -224,7 +224,7 @@ where
 		log::warn!("Unable to calculate duration, unknown sample counts are not yet supported");
 		return Ok(properties);
 	}
-	
+
 	if total_samples == 0 || properties.sample_rate == 0 {
 		if parse_mode == ParsingMode::Strict {
 			decode_err!(@BAIL WavPack, "Unable to calculate duration (sample count == 0 || sample rate == 0)")
@@ -302,20 +302,29 @@ fn get_extended_meta_info(
 	block_content: &[u8],
 	properties: &mut WavPackProperties,
 ) -> Result<()> {
-	let mut index = 0;
-	let block_size = block_content.len();
-	while index < block_size {
-		let id = block_content[index];
-		index += 1;
+	let reader = &mut &block_content[..];
+	loop {
+		if reader.len() < 2 {
+			break;
+		}
 
-		let mut size = u32::from(block_content[index]) << 1;
-		index += 1;
+		let id = reader.read_u8()?;
+		let mut size = u32::from(reader.read_u8()?) << 1;
 
 		let is_large = id & ID_FLAG_LARGE_SIZE > 0;
 		if is_large {
-			size += u32::from(block_content[index]) << 9;
-			size += u32::from(block_content[index + 1]) << 17;
-			index += 2;
+			size += u32::from(reader.read_u8()?) << 9;
+			size += u32::from(reader.read_u8()?) << 17;
+		}
+
+		if size == 0 {
+			// Empty blocks may not *always* be valid, but we only care about the validity
+			// of a few blocks.
+			continue;
+		}
+
+		if (size as usize) > reader.len() {
+			err!(SizeMismatch);
 		}
 
 		if id & ID_FLAG_ODD_SIZE > 0 {
@@ -324,16 +333,20 @@ fn get_extended_meta_info(
 
 		match id & 0x3F {
 			ID_NON_STANDARD_SAMPLE_RATE => {
-				properties.sample_rate =
-					(&mut &block_content[index..]).read_u24::<LittleEndian>()?;
+				if size < 3 {
+					decode_err!(@BAIL WavPack, "Encountered an invalid block size for non-standard sample rate");
+				}
+
+				properties.sample_rate = reader.read_u24::<LittleEndian>()?;
+				size -= 3;
 			},
 			ID_DSD => {
 				if size <= 1 {
 					decode_err!(@BAIL WavPack, "Encountered an invalid DSD block size");
 				}
 
-				let mut rate_multiplier = u32::from(block_content[index]);
-				index += 1;
+				let mut rate_multiplier = u32::from(reader.read_u8()?);
+				size -= 1;
 
 				if rate_multiplier > 30 {
 					parse_mode_choice!(
@@ -345,37 +358,35 @@ fn get_extended_meta_info(
 
 				rate_multiplier = 1 << rate_multiplier;
 				properties.sample_rate = properties.sample_rate.wrapping_mul(rate_multiplier);
-
-				// Skip DSD mode
-				index += 1;
 			},
 			ID_MULTICHANNEL => {
 				if size <= 1 {
 					decode_err!(@BAIL WavPack, "Unable to extract channel information");
 				}
 
-				properties.channels = u16::from(block_content[index]);
-				index += 1;
-
-				let reader = &mut &block_content[index..];
+				properties.channels = u16::from(reader.read_u8()?);
 
 				// size - (id length + channel length)
 				let s = size - 2;
 				match s {
 					0 => {
 						let channel_mask = reader.read_u8()?;
+						size -= 1;
 						properties.channel_mask = ChannelMask(u32::from(channel_mask));
 					},
 					1 => {
 						let channel_mask = reader.read_u16::<LittleEndian>()?;
+						size -= 2;
 						properties.channel_mask = ChannelMask(u32::from(channel_mask));
 					},
 					2 => {
 						let channel_mask = reader.read_u24::<LittleEndian>()?;
+						size -= 3;
 						properties.channel_mask = ChannelMask(channel_mask);
 					},
 					3 => {
 						let channel_mask = reader.read_u32::<LittleEndian>()?;
+						size -= 4;
 						properties.channel_mask = ChannelMask(channel_mask);
 					},
 					4 => {
@@ -383,6 +394,8 @@ fn get_extended_meta_info(
 						properties.channels += 1;
 
 						let channel_mask = reader.read_u24::<LittleEndian>()?;
+						size -= 4;
+
 						properties.channel_mask = ChannelMask(channel_mask);
 					},
 					5 => {
@@ -390,18 +403,26 @@ fn get_extended_meta_info(
 						properties.channels += 1;
 
 						let channel_mask = reader.read_u32::<LittleEndian>()?;
+						size -= 5;
+
 						properties.channel_mask = ChannelMask(channel_mask);
 					},
 					_ => decode_err!(@BAIL WavPack, "Encountered invalid channel info size"),
 				}
 			},
-			_ => {
-				index += size as usize;
-			},
+			_ => {},
 		}
 
+		// Skip over any remaining block size
+		if (size as usize) > reader.len() {
+			err!(SizeMismatch);
+		}
+
+		let (_, rem) = reader.split_at(size as usize);
+		*reader = rem;
+
 		if id & ID_FLAG_ODD_SIZE > 0 {
-			index += 1;
+			let _ = reader.read_u8()?;
 		}
 	}
 
